==> owncloud_5.0.8%2Bdfsg-1.debian.tar.gz: debian/repack.sh <==
#!/bin/sh
# Repackage upstream source to exclude non-distributable files
# should be called as "repack.sh --upstream-source <ver> <downloaded file>
# (for example, via uscan)

set -e
set -u

VER="$2+dfsg"
FILE="$3"
PKG=`dpkg-parsechangelog|grep ^Source:|sed 's/^Source: //'`

REPACK_DIR="$PKG-$VER.orig" # DevRef § 6.7.8.2

echo -e "\nRepackaging $FILE\n"

DIR=`mktemp -d ./tmpRepackXXXXXX`
trap "rm -rf \"$DIR\"" QUIT INT EXIT

# Create an extra directory to cope with rootless tarballs
UP_BASE="$DIR/unpack"
mkdir "$UP_BASE"
tar xjf "$FILE" -C "$UP_BASE"

if [ `ls -1 "$UP_BASE" | wc -l` -eq 1 ]; then
	# Tarball does contain a root directory
	UP_BASE="$UP_BASE/`ls -1 "$UP_BASE"`"
fi

## Remove stuff
rm -vr $UP_BASE/3rdparty/timepicker/css/include
rm -v $UP_BASE/core/js/jquery-1.7.2.min.js
rm -v $UP_BASE/core/js/jquery-ui-1.10.0.custom.js
rm -v  $UP_BASE/core/doc/*/_static/bootstrap.css
rm -v  $UP_BASE/core/doc/*/_static/bootstrap.js
rm -v  $UP_BASE/core/doc/*/_static/bootstrap-responsive.css
rm -v  $UP_BASE/core/doc/*/_static/jquery.js
rm -v  $UP_BASE/core/doc/*/_static/underscore.js

# following contain incompatible license with Debian
rm -vr $UP_BASE/3rdparty/Console
rm -vr $UP_BASE/3rdparty/fontawesome/docs
rm -vr $UP_BASE/apps/files_encryption/3rdparty/Crypt_Blowfish
rm -v $UP_BASE/apps/files_pdfviewer/3rdparty/pdfjs/compressed.tracemonkey-pldi-09.pdf
rm -v $UP_BASE/apps/files_texteditor/js/aceeditor/worker-*
## End

mv "$UP_BASE" "$DIR/$REPACK_DIR"

# Using a pipe hides tar errors!
tar cfC "$DIR/repacked.tar" "$DIR" "$REPACK_DIR"
bzip2 -9 < "$DIR/repacked.tar" > "$DIR/repacked.tar.bz2"
RESULTING_FILE="$(dirname $FILE)/${PKG}_${VER}.orig.tar.bz2"
mv "$DIR/repacked.tar.bz2" "$RESULTING_FILE"
rm -f "$FILE"

echo "*** $FILE repackaged"
echo "*** Please note that the upstream version must be $VER since we are repackaging the tarball!"

==> owncloud_5.0.11%2Bdfsg-1.debian.tar.gz: debian/repack.sh <==
#!/bin/sh
# Repackage upstream source to exclude non-distributable files
# should be called as "repack.sh --upstream-source <ver> <downloaded file>
# (for example, via uscan)

set -e
set -u

VER="$2+dfsg"
FILE="$3"
PKG=`dpkg-parsechangelog|grep ^Source:|sed 's/^Source: //'`

REPACK_DIR="$PKG-$VER.orig" # DevRef § 6.7.8.2

echo -e "\nRepackaging $FILE\n"

DIR=`mktemp -d ./tmpRepackXXXXXX`
trap "rm -rf \"$DIR\"" QUIT INT EXIT

# Create an extra directory to cope with rootless tarballs
UP_BASE="$DIR/unpack"
mkdir "$UP_BASE"
tar xjf "$FILE" -C "$UP_BASE"

if [ `ls -1 "$UP_BASE" | wc -l` -eq 1 ]; then
	# Tarball does contain a root directory
	UP_BASE="$UP_BASE/`ls -1 "$UP_BASE"`"
fi

## Remove stuff
rm -vr $UP_BASE/3rdparty/timepicker/css/include
rm -v $UP_BASE/core/js/jquery-1.7.2.min.js
rm -v $UP_BASE/core/js/jquery-ui-1.10.0.custom.js
rm -v  $UP_BASE/core/doc/*/_static/bootstrap.css
rm -v  $UP_BASE/core/doc/*/_static/bootstrap.js
rm -v  $UP_BASE/core/doc/*/_static/bootstrap-responsive.css
rm -v  $UP_BASE/core/doc/*/_static/jquery.js
rm -v  $UP_BASE/core/doc/*/_static/underscore.js

# following contain incompatible license with Debian
rm -vr $UP_BASE/3rdparty/Console
rm -vr $UP_BASE/3rdparty/fontawesome/docs
rm -vr $UP_BASE/apps/files_encryption/3rdparty/Crypt_Blowfish
rm -v $UP_BASE/apps/files_pdfviewer/3rdparty/pdfjs/compressed.tracemonkey-pldi-09.pdf
rm -v $UP_BASE/apps/files_texteditor/js/vendor/ace/src-noconflict/worker-*
## End

mv "$UP_BASE" "$DIR/$REPACK_DIR"

# Using a pipe hides tar errors!
tar cfC "$DIR/repacked.tar" "$DIR" "$REPACK_DIR"
bzip2 -9 < "$DIR/repacked.tar" > "$DIR/repacked.tar.bz2"
RESULTING_FILE="$(dirname $FILE)/${PKG}_${VER}.orig.tar.bz2"
mv "$DIR/repacked.tar.bz2" "$RESULTING_FILE"
rm -f "$FILE"

echo "*** $FILE repackaged"
echo "*** Please note that the upstream version must be $VER since we are repackaging the tarball!"
